from testcomponent import *
from testinputadapter import *
from testdecoding import *
from testgraphing import *
from testanalyzing import *
from testencoding import *
from unit_timeside import *

unittest.main(testRunner=TestRunner())
